__author__ = 'tolerious'
from django.conf.urls import patterns, url

from app import views
urlpatterns = patterns('',
                       url(r'^$', views.index, name='index'),
                       url(r'^token/$', views.accesstoken, name='accesstoken'),
                       )



from django.db import models
import requests, logging
from wechat_server import *
# Create your models here.

class AccessToken(models.Model):
    corpid = models.CharField(default='corpid', max_length=200)
    corpsecret = models.CharField(default='corpsecret', max_length=200)
    token = models.CharField(default='abc', max_length=500)
    aeskey = models.CharField(default='abc', max_length=1000)

    def __unicode__(self):
        return self.corpid + ";" + self.corpsecret

    def get_access_token(self):
        url = 'https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid='+ self.corpid+'&corpsecret=' + self.corpsecret
        r = requests.get(url, verify=False)
        try:
            access_token = r.json()['access_token']
            return access_token
        except Exception as e:
            logging.info(str(e))
            return 'Invalidate'


'''
Created on 03 19, 2015

@author: tolerious

'''
from models import AccessToken
from django.db import models
import requests, logging

class WeChatServer(models.Model):
    server_ip_list = models.CharField(default="",blank=True,max_length=1000)

    def get_wechat_server_ip_list(self):
        access_token = AccessToken.objects.get(id=1)
        token = access_token.get_access_token()
        url = "https://qyapi.weixin.qq.com/cgi-bin/getcallbackip?access_token=" + token
        r = requests.get(url, verify=False)
        try:
            ip_list = r.json()['ip_list']
            str = ""
            for i in ip_list:
                temp_i = i + ","
                str += temp_i
            self.server_ip_list = str
            return ip_list
        except Exception as e:
            return ""
            logging.info(str(e))
